<?php

namespace App\Http\Controllers;

use App\Models\Cash;
use App\Models\Collectors;
use App\Models\Donators;
use App\Models\Payment;
use App\Models\Receipt;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;

class PaymentController extends Controller
{
  
    public function index(Request $request)
    {
        $collectorsdata = Collectors::all();

        $data_query = Payment::select('*');
      
        if($request->input('from_date')){

            $from_date = $request->input('from_date');
            $to_date = $request->input('to_date');
        
            $data_query = $data_query->whereBetween('entry_date',[$from_date,$to_date]);
        }
        // else{

        //     $current_date = date('Y-m-d');
        //     $data_query = $data_query->where('entry_date',$current_date);
        // }

        if($request->input('receiver_id')){

            $data_query->where('collectors_id',$request->input('receiver_id'));
        }

        // if($request->input('donator_id')){

        //     $data_query->where('donators_id',$request->input('donator_id'));
        // }
       
        $data = $data_query->get();
            

        if($request->input('filter') == 'filter'){
            return view('payment.table-list',['data' => $data,'collectorsdata'=>$collectorsdata]);
        }else{
            return view('payment.list',['data' => $data,'collectorsdata'=>$collectorsdata]);
        }
    }


    public function create()
    {
        $collectorsdata = Collectors::all();

        return view('payment.create',['collectorsdata'=>$collectorsdata]); 
    }

   
    public function store(Request $request)
    {
        $prefix = "PAY";
        $sequence_padding = $this->generate_sequence();
        $payment_no =  $prefix."".$sequence_padding;    
        
        $paymentEntry = new Payment();
        
        $paymentEntry->entry_date = Carbon::parse($request->input('entry_date'))->format('Y-m-d');
        $paymentEntry->prefix = $prefix;
        $paymentEntry->sequence = $this->max_no;
        $paymentEntry->payment_no = $payment_no; 
        $paymentEntry->collectors_id = $request->input('collector_name');
        $paymentEntry->received_by = $request->input('received_by');
        $paymentEntry->amount = $request->input('amount');
        $paymentEntry->description = $request->input('notes');
        $paymentEntry->created_by = Auth::user()->id;
        $paymentEntry->save();

        $cashTransaction = new Cash();
        $cashTransaction->entry_date = Carbon::parse($request->input('entry_date'))->format('Y-m-d');
        $cashTransaction->refer = "Payment";
        $cashTransaction->refer_id = $paymentEntry->id;
        $cashTransaction->collectors_id = $request->input('collector_name');
        $cashTransaction->credit = $request->input('amount');
        $cashTransaction->created_by = Auth::user()->id;
        $cashTransaction->save();

         return redirect('/payment')->with('success','Payment Entry Created For '.$payment_no);
    }

    
    public function show($id)
    {
    }

    
    public function edit($id)
    {
        $collectorsdata = Collectors::all();

        $data = Payment::find($id);

       return view('payment.edit',['data' => $data,'collectorsdata'=>$collectorsdata]);
    }

    
    public function update(Request $request, $id)
    {
        $paymentEntry = Payment::find($id);
        
        $paymentEntry->entry_date = Carbon::parse($request->input('entry_date'))->format('Y-m-d');
        $paymentEntry->collectors_id = $request->input('collector_name');
        $paymentEntry->received_by = $request->input('received_by');
        $paymentEntry->amount = $request->input('amount');
        $paymentEntry->description = $request->input('notes');
        $paymentEntry->created_by = Auth::user()->id;
        $paymentEntry->save();

        $cashTransactionDel = Cash::where('refer_id',$id)->where('refer','Payment')->delete();

        $cashTransaction = new Cash();
        $cashTransaction->entry_date = Carbon::parse($request->input('entry_date'))->format('Y-m-d');
        $cashTransaction->refer = "Payment";
        $cashTransaction->refer_id = $paymentEntry->id;
        $cashTransaction->collectors_id = $request->input('collector_name');
        $cashTransaction->credit = $request->input('amount');
        $cashTransaction->created_by = Auth::user()->id;
        $cashTransaction->save();

         return redirect('/payment')->with('success','Receipt Entry Updated For '.$paymentEntry->payment_no);
    }

   
    public function destroy($id)
    {
        $paymentEntry = Payment::find($id);

        $cashTransactionDel = Cash::where('refer_id',$id)->where('refer','Payment')->delete();

        $paymentEntry->delete();
    }

    public function generate_sequence(){
        
        $paymentEntry = new Payment();
        $count = $paymentEntry->count('id');
        
        if($count == 0){
            
            $max_seq = 1;        
        }
        else{
            
            $max_seq = $paymentEntry->max('sequence') + 1;  
        }

        $this->max_no = $max_seq;
        $seq_padding = Str::of($max_seq)->padLeft(5,'0');

        return $seq_padding;
    }
}
